@@ -11,11 +11,9 @@ class LinuxVolumeFilter(NetBoxModelFilterSet):
     class Meta:
         model = LinuxVolume
         fields = [
-            "vg_name",
-            "lv_name",
-            "fs",
+            "size",
             "path",
-            "description"
+            "description",
         ]
 
     def search(self, queryset, name, value):
@@ -23,9 +21,7 @@ class LinuxVolumeFilter(NetBoxModelFilterSet):
         if not value.strip():
             return queryset
         qs_filter = (
-            Q(vg_name__icontains=value)
-            | Q(lv_name__icontains=value)
-            | Q(fs__icontains=value)
+            Q(size__icontains=value)
             | Q(path__icontains=value)
         )
         return queryset.filter(qs_filter)
