@@ -68,7 +68,8 @@ class Drive(NetBoxModel):
         return PhysicalVolume.objects.filter(drive=self).count()
 
     def left_free_space(self):
-        current_partition_allocated_space = Partition.objects.filter(drive=self).aggregate(sum=Sum("size")).get("sum") or 0
+        current_partition_allocated_space = Partition.objects.filter(drive=self).aggregate(sum=Sum("size")).get(
+            "sum") or 0
         return self.size - current_partition_allocated_space
 
 
@@ -113,8 +114,8 @@ class Partition(NetBoxModel):
 
     def clean(self, *args, **kwargs):
         total_allocated_space = Partition.objects.filter(drive=self.drive).aggregate(sum=Sum("size")).get("sum") or 0
-        current_partition_size = Partition.objects.filter(drive=self.drive, id=self.pk)\
-            .aggregate(sum=Sum("size")).get("sum") or 0
+        current_partition_size = Partition.objects.filter(drive=self.drive, id=self.pk) \
+                                     .aggregate(sum=Sum("size")).get("sum") or 0
         if self.size is None:
             raise ValidationError(
                 {
@@ -142,8 +143,8 @@ class Partition(NetBoxModel):
                     }
                 )
 
-    def physicalvolumes_count(self):
-        return PhysicalVolume.objects.filter(partition=self).count()
+    def get_affiliated_physical_volume(self):
+        return PhysicalVolume.objects.filter(partition=self).first()
 
 
 class VolumeGroup(NetBoxModel):
@@ -172,9 +173,18 @@ class VolumeGroup(NetBoxModel):
     def physical_volume_count(self):
         return PhysicalVolume.objects.filter(vg=self).count()
 
+    def logical_volume_count(self):
+        return LogicalVolume.objects.filter(vg=self).count()
+
+    def get_total_affiliated_size(self):
+        total_sum = 0
+        for PV in PhysicalVolume.objects.filter(vg=self):
+            total_sum += PV.partition.size
+        return total_sum
+
 
 class PhysicalVolume(NetBoxModel):
-    partition = models.ForeignKey(
+    partition = models.OneToOneField(
         Partition,
         on_delete=models.CASCADE,
         related_name='partition_physicalvolume',
@@ -212,6 +222,10 @@ class PhysicalVolume(NetBoxModel):
     class Meta:
         ordering = ("partition", "description")
 
+    @property
+    def size(self):
+        return self.partition.size
+
 
 class Filesystem(NetBoxModel):
     filesystem = models.CharField(
