@@ -60,7 +60,7 @@ from netbox_storage.views import (
     LinuxVolumeBulkEditView,
     LinuxVolumeBulkDeleteView,
     LinuxVolumeView,
-    LinuxVolumeDeleteView, VolumeGroupPhysicalVolumeListView,
+    LinuxVolumeDeleteView, VolumeGroupPhysicalVolumeListView, VolumeGroupLogicalVolumeListView,
 )
 
 app_name = "netbox_storage"
@@ -154,6 +154,8 @@ urlpatterns = [
     ),
     path("volumegroup/<int:pk>/physicalvolume/", VolumeGroupPhysicalVolumeListView.as_view(),
          name="volumegroup_physicalvolumes"),
+    path("volumegroup/<int:pk>/logicalvolume/", VolumeGroupLogicalVolumeListView.as_view(),
+         name="volumegroup_logicalvolumes"),
     #
     # LogicalVolume urls
     #
